@@ -25,7 +25,8 @@ class TestDBManager(TestCase):
         else:
             db = DBManager(
                 debug_output_mode=True,
-                db_port=5434,
+                use_ssh=False,
+                ssh_remote_bind_port=5434,
                 db_name='test',
                 db_user='test',
                 db_password='test',
@@ -292,7 +293,8 @@ class TestDBManager(TestCase):
         # Test finding an unknown dtype
         with self.assertRaises(MissingDTypeFromTypes):
             db = MockMissingDTypeFromTypes(debug_output_mode=True,
-                                           db_port=5434,
+                                           use_ssh=False,
+                                           ssh_remote_bind_port=5434,
                                            db_name='test',
                                            db_user='test',
                                            db_password='test',
@@ -346,14 +348,30 @@ class MockMissingDTypeFromTypes(DBManager):
 
     def __init__(self,
                  debug_output_mode=None,
-                 db_port=None,
+                 use_ssh=False,
+                 ssh_key_path=None,
+                 ssh_host=None,
+                 ssh_port=None,
+                 ssh_user=None,
+                 ssh_remote_bind_address=None,
+                 ssh_remote_bind_port=None,
+                 ssh_local_bind_address=None,
+                 ssh_local_bind_port=None,
                  db_name=None,
                  db_user=None,
                  db_password=None,
                  db_schema=None,
                  db_host=None):
         super().__init__(debug_output_mode,
-                         db_port,
+                         use_ssh,
+                         ssh_key_path,
+                         ssh_host,
+                         ssh_port,
+                         ssh_user,
+                         ssh_remote_bind_address,
+                         ssh_remote_bind_port,
+                         ssh_local_bind_address,
+                         ssh_local_bind_port,
                          db_name,
                          db_user,
                          db_password,
